Crate kcr_nodeinfo_volcano_sh

Crate kcr_nodeinfo_volcano_sh 

This crate contains kube-rs compatible bindings for Kubernetes custom resources for the nodeinfo.volcano.sh group. Each binding is generated with kopium, updated and released weekly.

Available Custom Resources

nodeinfo.volcano.sh/v1alpha1

  • Numatopology

Modules

v1alpha1